==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaListFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaListFluent<A extends FlowSchemaListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,FlowSchema item);
  public A setToItems(Integer index,FlowSchema item);
  public A addToItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public A addAllToItems(Collection<FlowSchema> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public A removeAllFromItems(Collection<FlowSchema> items);
  public A removeMatchingFromItems(Predicate<FlowSchemaBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FlowSchema> getItems();
  public List<FlowSchema> buildItems();
  public FlowSchema buildItem(Integer index);
  public FlowSchema buildFirstItem();
  public FlowSchema buildLastItem();
  public FlowSchema buildMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public A withItems(List<FlowSchema> items);
  public A withItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public Boolean hasItems();
  public FlowSchemaListFluent.ItemsNested<A> addNewItem();
  public FlowSchemaListFluent.ItemsNested<A> addNewItemLike(FlowSchema item);
  public FlowSchemaListFluent.ItemsNested<A> setNewItemLike(Integer index,FlowSchema item);
  public FlowSchemaListFluent.ItemsNested<A> editItem(Integer index);
  public FlowSchemaListFluent.ItemsNested<A> editFirstItem();
  public FlowSchemaListFluent.ItemsNested<A> editLastItem();
  public FlowSchemaListFluent.ItemsNested<A> editMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,FlowSchemaFluent<FlowSchemaListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaListFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaListFluent<A extends FlowSchemaListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,FlowSchema item);
  public A setToItems(int index,FlowSchema item);
  public A addToItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public A addAllToItems(Collection<FlowSchema> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public A removeAllFromItems(Collection<FlowSchema> items);
  public A removeMatchingFromItems(Predicate<FlowSchemaBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FlowSchema> getItems();
  public List<FlowSchema> buildItems();
  public FlowSchema buildItem(int index);
  public FlowSchema buildFirstItem();
  public FlowSchema buildLastItem();
  public FlowSchema buildMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public A withItems(List<FlowSchema> items);
  public A withItems(io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1.FlowSchema... items);
  public Boolean hasItems();
  public FlowSchemaListFluent.ItemsNested<A> addNewItem();
  public FlowSchemaListFluent.ItemsNested<A> addNewItemLike(FlowSchema item);
  public FlowSchemaListFluent.ItemsNested<A> setNewItemLike(int index,FlowSchema item);
  public FlowSchemaListFluent.ItemsNested<A> editItem(int index);
  public FlowSchemaListFluent.ItemsNested<A> editFirstItem();
  public FlowSchemaListFluent.ItemsNested<A> editLastItem();
  public FlowSchemaListFluent.ItemsNested<A> editMatchingItem(Predicate<FlowSchemaBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,FlowSchemaFluent<FlowSchemaListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
